==> segatex-8.500.tar.gz: segatex-8.500/src/segatex_selinuxpath.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXSELINUXPATH_H
#define SEGATEXSELINUXPATH_H

#include <QPushButton>
#include <qdialog.h>
#include <qdir.h>
#include <q3textedit.h>
#include <Q3VBoxLayout>
#include <Q3HBoxLayout>

#include <selinux/selinux.h>

class QMessageBox;

class SegatexSelinuxpath: public QDialog
{
	Q_OBJECT
public:
	SegatexSelinuxpath(QWidget *parent = 0, const char *name = 0);
public slots:
	void segatex_selinuxpath_base_process();
	void readFromOutputFile();
signals:
protected:
private slots:
private:
	Q3TextEdit *textEdit1;
	QPushButton *closeButton;
	Q3VBoxLayout *mainLayout;
	Q3HBoxLayout *footLayout;

	QString seuser_string;
	QString seuser_str;
	QString list_str;
	QDir dir;
	QString path;
	QString name;
	QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;

	QString outputfile_str;
        QStringList::Iterator it_d;
        QStringList files;
};

#endif

==> segatex-8.640.tar.gz: segatex-8.640/src/segatex_selinuxpath.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXSELINUXPATH_H
#define SEGATEXSELINUXPATH_H

#include <QPushButton>
#include <QDialog>
#include <QDir>
#include <QTextEdit>
#include <QVBoxLayout>
#include <QHBoxLayout>

#include <selinux/selinux.h>

class QMessageBox;

class SegatexSelinuxpath: public QDialog
{
	Q_OBJECT
public:
	SegatexSelinuxpath(QWidget *parent = 0, const char *name = 0);
public slots:
	void segatex_selinuxpath_base_process();
	void readFromOutputFile();
signals:
protected:
private slots:
private:
	QTextEdit *textEdit1;
	QPushButton *closeButton;
	QVBoxLayout *mainLayout;
	QHBoxLayout *footLayout;

	QString seuser_string;
	QString seuser_str;
	QString list_str;
	QDir dir;
	QString path;
	QString name;
	QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;

	QString outputfile_str;
        QStringList::Iterator it_d;
        QStringList files;
};

#endif
